monotone-commits-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Monotone-commits-diffs] net.venge.monotone: 124bf7df83033d052407976042b


From: code
Subject: [Monotone-commits-diffs] net.venge.monotone: 124bf7df83033d052407976042ba766a96c77206
Date: Wed, 25 Apr 2012 14:35:23 +0200 (CEST)

revision:            124bf7df83033d052407976042ba766a96c77206
date:                2012-04-25T11:42:11
author:              address@hidden
branch:              net.venge.monotone
changelog:
* src/gzip.hh: correct condition for adding a custom Memory_Exhaustion
  exception. Make it more like what Botan itself defined. Enables
  compatibility with Botan down to 1.6.3, again.

manifest:
format_version "1"

new_manifest [ce39337a53f9712ca5a7f61349446eaf988dbbe0]

old_revision [a0ed177b60caee5cf304c01d83e75812af1225e1]

patch "src/gzip.hh"
 from [aff9da63bb22366bccf69c2d75ee7790406d2455]
   to [17093f66e365b3730a49ef1910295f622972c36e]
============================================================
--- src/gzip.hh	aff9da63bb22366bccf69c2d75ee7790406d2455
+++ src/gzip.hh	17093f66e365b3730a49ef1910295f622972c36e
@@ -13,10 +13,17 @@ namespace Botan {
 
 namespace Botan {
 
-#if BOTAN_VERSION_CODE < BOTAN_VERSION_CODE_FOR(1,9,4)
-// Only 1.9.4 and newer export the Memory_Exception. Give this gzip
-// implementation something compatible to work with.
-typedef std::bad_alloc Memory_Exhaustion;
+#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,7,12) && \
+  BOTAN_VERSION_CODE < BOTAN_VERSION_CODE_FOR(1,9,4)
+// Botan versions between 1.7.12 and 1.9.3 (including) keep their
+// Memory_Exception private. Give this gzip implementation something
+// compatible to work with.
+class Memory_Exhaustion : public Exception
+{
+public:
+  Memory_Exhaustion() :
+    Exception("Ran out of memory, allocation failed") {}
+};
 #endif
 
 namespace GZIP {

reply via email to

[Prev in Thread] Current Thread [Next in Thread]